@@ -1,5 +1,4 @@
 from __future__ import annotations
-
 import numpy as np
 import math
 from scipy.spatial.transform import Rotation as R
@@ -8,9 +7,9 @@ from typing import Union, Tuple, Sequence, Optional
 from dataclasses import dataclass
 
 RotationMatrixLike = Union[Sequence[Sequence[float]], np.ndarray, "RotationMatrix"]
-VectorLike = Union[Sequence[float], np.ndarray, "Vector", "Point"]
-QuaternionTuple = Tuple[float, float, float, float]
 VectorTuple = Tuple[float, float, float]
+VectorLike = Union[Sequence[float], VectorTuple, np.ndarray, "Vector", "Point"]
+QuaternionTuple = Tuple[float, float, float, float]
 
 from .linalg import (
     add_vec_vec,
@@ -523,12 +522,6 @@ class Point:
     It is subject to translations and rotations of frame transformations.
     """
 
-    # __array_interface__ = {
-    #     "shape": (3,),
-    #     "typestr": "|f8",
-    #     "version": 3,
-    # }
-
     def __init__(self, p: VectorLike):
         """Initialize a Point from a sequence of X,Y,Z coordinates.
 
@@ -585,30 +578,30 @@ class Point:
     def __array__(self):
         return self._a
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: int):
         return self._a[key]
 
-    def __add__(self, other):
+    def __add__(self, other: VectorLike) -> Union[Point, np.ndarray]:
         if isinstance(other, Point):
             return Point(self._a + other._a)
         elif isinstance(other, Vector):
             return Point(self._a + other._a)
         else:
-            return self._a + other
+            return self._a + np.array(other)
 
     __radd__ = __add__
 
-    def __sub__(self, other):
+    def __sub__(self, other: VectorLike) -> Union[Vector, Point, np.ndarray]:
         if isinstance(other, Point):
             return Vector(self._a - other._a)
         elif isinstance(other, Vector):
             return Point(self._a - other._a)
         else:
-            return self._a - other
+            return self._a - np.array(other)
 
     __rsub__ = __sub__
 
-    def __matmul__(self, other: Union[VectorLike, RotationMatrixLike]) -> float:
+    def __matmul__(self, other: Union[VectorLike, RotationMatrixLike]) -> Union[float, np.ndarray]:
         return np.dot(self._a, np.asarray(other))
 
     def __rmatmul__(self, other: Union[VectorLike, RotationMatrixLike]) -> float:
